svn commit: r332382 - head/sys/netinet

Jonathan T. Looney jtl at FreeBSD.org
Tue Apr 10 17:00:38 UTC 2018


Author: jtl
Date: Tue Apr 10 17:00:37 2018
New Revision: 332382
URL: https://svnweb.freebsd.org/changeset/base/332382

Log:
  Add missing header change from r332381.
  
  Sponsored by:	Netflix, Inc.
  Pointy hat:	jtl

Modified:
  head/sys/netinet/tcp_var.h

Modified: head/sys/netinet/tcp_var.h
==============================================================================
--- head/sys/netinet/tcp_var.h	Tue Apr 10 16:59:36 2018	(r332381)
+++ head/sys/netinet/tcp_var.h	Tue Apr 10 17:00:37 2018	(r332382)
@@ -688,11 +688,14 @@ void	tcp_inptoxtp(const struct inpcb *, struct xtcpcb 
 #endif
 
 /*
  * TCP function name-to-id mapping exported to user-land via sysctl(3).
  */
-struct tcp_function_id {
+struct tcp_function_info {
+	uint32_t	tfi_refcnt;
 	uint8_t		tfi_id;
 	char		tfi_name[TCP_FUNCTION_NAME_LEN_MAX];
+	char		tfi_alias[TCP_FUNCTION_NAME_LEN_MAX];
 };
 
 /*
@@ -688,11 +688,14 @@ void	tcp_inptoxtp(const struct inpcb *, struct xtcpcb 
 
 /*
- * TCP function name-to-id mapping exported to user-land via sysctl(3).
+ * TCP function information (name-to-id mapping, aliases, and refcnt)
+ * exported to user-land via sysctl(3).
  */


More information about the svn-src-all mailing list